@@ -25,20 +25,19 @@ sub build_binaries {
     ### DEVEL BUILD ###
     @imtargets  = qw[im im_process im_jp2 im_fftw]; #xxx im_capture removed
     @cdtargets  = qw[cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl]; #xxx add cdcontextplus
-    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iupgl iupim iupimglib iupole iupweb iuptuio];
+    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupole iupweb iuptuio];
   }
   else {
     @imtargets  = qw[im];
     @cdtargets  = qw[cd_freetype cd];
-    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iupgl iupim iupimglib iupole];
+    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupole];
   }
 
   #make options
   my @makeopts   = qw[USE_NODEPEND=Yes];
   
-  #XXX-FIXME
-  #push(@makeopts, 'EXTRA_CFLAGS=-DIUP_IMGLIB_LARGE') if $self->notes('build_large_imglib');
-  warn "Large built-in images not supported on Cygwin platform\n" if $self->notes('build_large_imglib');
+  #extra options for iup/imglib
+  push(@makeopts, 'USE_IUP_IMGLIB_LARGE=1') if $self->notes('build_large_imglib');
 
   #store debug info into ConfigData
   $self->config_data('info_imtargets', \@imtargets);
